@@ -1,3 +1,5 @@
+#![feature(no_sanitize)]
+
 use std::{
     fmt::Display,
     ops::{Add, AddAssign},
@@ -13,7 +15,7 @@ mod result;
 mod runner;
 pub use result::ShumaiResult;
 pub use runner::run;
-pub use shumai_config_impl::{shumai_config, ShumaiConfig};
+pub use shumai_config_impl::{config, ShumaiConfig};
 
 pub mod __dep {
     pub use colored;
