@@ -5,8 +5,8 @@ use serde_json::Value;
 use std::{path::PathBuf, str::FromStr};
 
 use crate::{
-    counters::{pcm::PcmStats, perf::PerfCounter},
     env::RunnerEnv,
+    metrics::{disk_io::DiskUsage, pcm::PcmStats, perf::PerfCounter},
     BenchConfig,
 };
 
@@ -74,4 +74,5 @@ pub struct ThreadResult<R: Serialize + Clone> {
     pub results: Vec<R>,
     pub pcm: Vec<PcmStats>,
     pub perf: Option<PerfCounter>,
+    pub disk_usage: DiskUsage,
 }
